#!/bin/bash
set -e
set -o pipefail

export DB_IMAGE="$IMAGE_REGISTRY_URL/$DB_IMAGE:$RELEASE"
export DB_COMPOSE="$DB_CONFIG_DIR/db_compose.yml"
export TIMEOUT=180

__check_db() {
  log_proc_msg "Checking $COMPONENT container status on: $DB_IP:$DB_PORT"
  platform_exec "check_service_connection" "$DB_IP" "$DB_PORT" "$COMPONENT" "$TIMEOUT"
}

__generate_compose_config() {
  log_proc_msg "Generating database compose config"

  local compose_template="$INSTALLER_SCRIPTS_DIR/configs/db_compose.yml.template"
  cp -vr $compose_template $DB_COMPOSE

  log_proc_msg "Updating component name"
  sed -i 's#{{COMPONENT}}#'$COMPONENT'#g' $DB_COMPOSE

  log_proc_msg "Updating db Image"
  sed -i 's#{{DB_IMAGE}}#'$DB_IMAGE'#g' $DB_COMPOSE

  log_proc_msg "Updating db port"
  sed -i 's#{{DB_PORT}}#'$DB_PORT'#g' $DB_COMPOSE

  log_proc_msg "Updating db password"
  sed -i 's#{{DB_PASSWORD}}#'$DB_PASSWORD'#g' $DB_COMPOSE

  log_proc_msg "Updating db username"
  sed -i 's#{{DB_USER}}#'$DB_USER'#g' $DB_COMPOSE

  log_proc_msg "Updating db name"
  sed -i 's#{{DB_NAME}}#'$DB_NAME'#g' $DB_COMPOSE

  log_proc_msg "Updating db data directory"
  sed -i 's#{{DB_DATA_DIR}}#'$DB_DATA_DIR'#g' $DB_COMPOSE

  log_proc_msg "Updating db config directory"
  sed -i 's#{{DB_CONFIG_DIR}}#'$DB_CONFIG_DIR'#g' $DB_COMPOSE
}

__run_db() {
  log_proc_msg "Running database container"
  docker-compose \
    --file $DB_COMPOSE down || true

  docker-compose \
    --file $DB_COMPOSE \
    up \
    --detach $COMPONENT
}

main() {
  log_proc_msg "Booting database"
  __generate_compose_config
  __run_db
  __check_db
  log_proc_msg "Database container successfully running"
}

main
