#!/bin/bash
set -e
set -o pipefail

export MSG_COMPOSE="$MSG_CONFIG_DIR/msg_compose.yml"

__generate_compose_config() {
  log_proc_msg "Generating msg compose config"

  local compose_template="$INSTALLER_SCRIPTS_DIR/configs/msg_compose.yml.template"
  cp -vr $compose_template $MSG_COMPOSE

  log_proc_msg "Updating component name"
  sed -i 's#{{COMPONENT}}#'$COMPONENT'#g' $MSG_COMPOSE

  log_proc_msg "Updating msg image"
  sed -i 's#{{MSG_IMAGE}}#'$MSG_IMAGE'#g' $MSG_COMPOSE

  log_proc_msg "Updating msg port"
  sed -i 's#{{RABBITMQ_PORT}}#'$RABBITMQ_PORT'#g' $MSG_COMPOSE

  log_proc_msg "Updating msg admin port"
  sed -i 's#{{RABBITMQ_ADMIN_PORT}}#'$RABBITMQ_ADMIN_PORT'#g' $MSG_COMPOSE

  log_proc_msg "Updating msg data directory"
  sed -i 's#{{MSG_DATA_DIR}}#'$MSG_DATA_DIR'#g' $MSG_COMPOSE

  log_proc_msg "Updating msg config directory"
  sed -i 's#{{MSG_CONFIG_DIR}}#'$MSG_CONFIG_DIR'#g' $MSG_COMPOSE
}

__run_msg() {
  log_proc_msg "Running rabbitmq container"
  docker-compose \
    --file $MSG_COMPOSE down || true

  docker-compose \
    --file $MSG_COMPOSE \
    up \
    --detach $COMPONENT

  log_proc_msg "Rabbitmq container successfully running"
}

__check_msg() {
  log_proc_msg "Checking rabbitmq container status on: $RABBITMQ_IP:$RABBITMQ_PORT"

  platform_exec "check_service_connection" "$RABBITMQ_IP" "$RABBITMQ_PORT" "$COMPONENT"
  platform_exec "check_service_connection" "$RABBITMQ_IP" "$RABBITMQ_ADMIN_PORT" "MSG_ADMIN"
}


main() {
  log_proc_msg "Installing RabbitMQ in a container"
  __generate_compose_config
  __run_msg
  __check_msg
}

main
