#!/bin/bash
set -e
set -o pipefail

export VAULT_COMPOSE="$VAULT_CONFIG_DIR/vault_compose.yml"

__generate_compose_config() {
  log_proc_msg "Generating vault compose config"

  local compose_template="$INSTALLER_SCRIPTS_DIR/configs/vault_compose.yml.template"
  cp -vr $compose_template $VAULT_COMPOSE

  log_proc_msg "Updating component name"
  sed -i 's#{{COMPONENT}}#'$COMPONENT'#g' $VAULT_COMPOSE

  log_proc_msg "Updating vault image"
  sed -i 's#{{VAULT_IMAGE}}#'$VAULT_IMAGE'#g' $VAULT_COMPOSE

  log_proc_msg "Updating vault port"
  sed -i 's#{{VAULT_PORT}}#'$VAULT_PORT'#g' $VAULT_COMPOSE

  log_proc_msg "Updating vault data directory"
  sed -i 's#{{VAULT_DATA_DIR}}#'$VAULT_DATA_DIR'#g' $VAULT_COMPOSE

  log_proc_msg "Updating vault config directory"
  sed -i 's#{{VAULT_CONFIG_DIR}}#'$VAULT_CONFIG_DIR'#g' $VAULT_COMPOSE
}

__run_vault() {
  log_proc_msg "Running vault container"
  docker-compose \
    --file $VAULT_COMPOSE down || true

  docker-compose \
    --file $VAULT_COMPOSE  \
    up \
    --detach $COMPONENT

  log_proc_msg "Vault container successfully running"
}

__check_vault() {
  log_proc_msg "Checking vault container status on: $VAULT_IP:$VAULT_PORT"
  platform_exec "check_service_connection" "$VAULT_IP" "$VAULT_PORT" "$COMPONENT"
}

main() {
  log_proc_msg "Installing vault in a container"
  __generate_compose_config
  __run_vault
  __check_vault
}

main
