#!/bin/bash
set -e
set -o pipefail

__create_registry_secret() {

  local existing_secret=$(sudo kubectl \
    --kubeconfig=$KUBECONFIG \
    get secrets -o json \
    | jq '.items[] | select(.metadata.name == "'$IMAGE_REGISTRY_SECRET'")')

  if [ ! -z "$existing_secret" ]; then
    log_proc_msg "Registry secret already exists, deleting it"
    local delete_secret=$(sudo kubectl \
      --kubeconfig=$KUBECONFIG \
      delete secret $IMAGE_REGISTRY_SECRET)
  fi

  log_proc_msg "Creating registry login secret: $IMAGE_REGISTRY_SECRET"
  local reg_secret=$(sudo kubectl \
    --kubeconfig=$KUBECONFIG \
    create secret generic $IMAGE_REGISTRY_SECRET \
    --from-file=.dockerconfigjson=$REGISTRY_CREDS \
    --type=kubernetes.io/dockerconfigjson
  )

}

main() {
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    log_proc_msg "No secrets required for devmode/onebox, skipping"
  else
    log_proc_marker "Creating secrets"
    __create_registry_secret
  fi
}

main
