#!/bin/bash
set -e
set -o pipefail

export COMPONENT="vault"
export VAULT_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"

__validate_vault_store() {
  log_proc_msg "Validating vault store script"

  if [ ! -d "$VAULT_CONFIG_DIR" ]; then
    log_proc_msg "Vault config dir not present, creating"
    mkdir -p "$VAULT_CONFIG_DIR"
  else
    log_proc_msg "Vault config dir already present"
  fi
}

__upsert_vault_store() {
  log_proc_msg "Upserting vault store in db"

  local vault_script_host_location="$INSTALLER_SCRIPTS_DIR/configs/vault_kv_store.sql"

  local upsert_cmd="PGHOST=$DB_IP \
    PGPORT=$DB_PORT \
    PGDATABASE=$DB_NAME \
    PGUSER=$DB_USER \
    PGPASSWORD=$DB_PASSWORD \
    psql \
    -U $DB_USER \
    -d $DB_NAME \
    -h $DB_IP \
    -v ON_ERROR_STOP=1 \
    -f $vault_script_host_location"

  eval "$upsert_cmd"
}

main() {
  log_proc_marker "Creating vault table in database"
  __validate_vault_store
  __upsert_vault_store
}

main
