#!/bin/bash
set -e
set -o pipefail

export COMPONENT="db"
export DB_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export LOGS_FILE="$RUNTIME_DIR/logs/$COMPONENT.log"

## Write logs of this script to component specific file
exec &> >(tee -a "$LOGS_FILE")

__validate_db_envs() {
  log_proc_msg "Creating master integration fields table"
  log_proc_msg "DB_CONFIG_DIR: $DB_CONFIG_DIR"
  log_proc_msg "LOGS_FILE: $LOGS_FILE"
}

__copy_drop_db_script() {
  log_proc_msg "Copying drop_database.sql to container"
  local script_host_location="$INSTALLER_SCRIPTS_DIR/configs/drop_database.sql"
  local script_container_location="$CONFIG_DIR/$COMPONENT/drop_database.sql"
  sudo cp -vr $script_host_location $script_container_location

  log_proc_msg "Successfully copied drop_database.sql to db container"
}

__drop_database() {
  log_proc_msg "Dropping database"

  local drop_db_script_location="$DB_CONFIG_DIR/drop_database.sql"
  local drop_db_cmd="sudo -u postgres \
    psql \
    -v ON_ERROR_STOP=1 \
    -f $drop_db_script_location"

  eval "$drop_db_cmd"
}

main() {
  log_proc_msg "Dropping database"
  if [ "$RUN_MODE" == "onebox" ] || [ "$RUN_MODE" == "devmode" ]; then
    __validate_db_envs
    __copy_drop_db_script
    __drop_database
  else
    log_proc_msg "Installer will not drop db since it is managed externally"
  fi
}

main
