#!/bin/bash
set -e
set -o pipefail

export TABLES_PATH="$INSTALLER_SCRIPTS_DIR/migrations/tables"
export RELATIONS_PATH="$INSTALLER_SCRIPTS_DIR/migrations/relations"
export DATA_PATH="$INSTALLER_SCRIPTS_DIR/migrations/data"
export TEMPLATES_PATH="$INSTALLER_SCRIPTS_DIR/migrations/templates"

__init_tables() {
  log_proc_msg "Initializing tables"

  for file_path in $TABLES_PATH/*.sql; do
    local init_table_cmd="PGPASSWORD=$DB_PASSWORD \
      psql \
      -U $DB_USER \
      -d $DB_NAME \
      -h $DB_IP \
      -p $DB_PORT \
      -v ON_ERROR_STOP=1 \
      -a -f $file_path > /dev/null"
    eval "$init_table_cmd"
  done
}

__init_relations() {
  log_proc_msg "Initializing relations"

  while read table_name; do
    file_path="${RELATIONS_PATH}/${table_name}.sql"
    if [ -f "$file_path" ]; then
      local init_relation_cmd="PGPASSWORD=$DB_PASSWORD \
        psql \
        -U $DB_USER \
        -d $DB_NAME \
        -h $DB_IP \
        -p $DB_PORT \
        -v ON_ERROR_STOP=1 \
        -a -f $file_path > /dev/null"
      eval "$init_relation_cmd"
    fi
  done < $RELATIONS_PATH/order.txt
}

__init_data() {
  log_proc_msg "Initializing data"

  if [ -f "$DATA_PATH/systemRuntimeTemplates.sql" ]; then
    rm $DATA_PATH/systemRuntimeTemplates.sql
  fi

  local release=$RELEASE
  if [ ! -z "$UPGRADE_VERSION" ]; then
    release=$UPGRADE_VERSION
  fi

  cp -vr "$TEMPLATES_PATH/systemRuntimeTemplates.sql.template" "$DATA_PATH/systemRuntimeTemplates.sql"
  sed -i 's#{{IMAGE_REGISTRY_URL}}#'$IMAGE_REGISTRY_URL'#g' $DATA_PATH/systemRuntimeTemplates.sql
  sed -i 's#{{RELEASE}}#'$release'#g' $DATA_PATH/systemRuntimeTemplates.sql

  if [ -f "$DATA_PATH/systemRuntimeLanguages.sql" ]; then
    rm $DATA_PATH/systemRuntimeLanguages.sql
  fi
  cp -vr "$TEMPLATES_PATH/systemRuntimeLanguages.sql.template" "$DATA_PATH/systemRuntimeLanguages.sql"
  sed -i 's#{{IMAGE_REGISTRY_URL}}#'$IMAGE_REGISTRY_URL'#g' $DATA_PATH/systemRuntimeLanguages.sql
  sed -i 's#{{RELEASE}}#'$release'#g' $DATA_PATH/systemRuntimeLanguages.sql

  while read table_name; do
    file_path="${DATA_PATH}/${table_name}.sql"
    if [ -f "$file_path" ]; then
      local init_data_cmd="PGPASSWORD=$DB_PASSWORD \
        psql \
        -U $DB_USER \
        -d $DB_NAME \
        -h $DB_IP \
        -p $DB_PORT \
        -v ON_ERROR_STOP=1 \
        -a -f $file_path > /dev/null"
      eval "$init_data_cmd"
    fi
  done < $DATA_PATH/order.txt
}

main() {
  __init_tables
  __init_relations
  __init_data
  log_proc_success "Database initialized"
}

main
