#!/bin/bash
set -e
set -o pipefail

__create_db_service() {
  log_proc_msg "Creating service for database"

  # TODO:
  # if ip:port already set, skip service creation
  # create service
  # get IP:PORT or service URL
  # set it in the config file
  local existing_service=$(kubectl \
    --kubeconfig=$KUBECONFIG \
    get services -o json \
    | jq '.items[] | select(.metadata.name == "db")')

  if [ -z "$existing_service" ]; then
    local db_service_template="$INSTALLER_SCRIPTS_DIR/configs/db_service.yml.template"
    local db_service="$DB_CONFIG_DIR/db_service.yml"

    cp -vr "$db_service_template" "$db_service"
    sed -i "s#{{DB_EXTERNAL_URL}}#$DB_EXTERNAL_URL#g" $db_service
    sed -i "s#{{DB_PORT}}#$DB_PORT#g" $db_service
    kubectl \
      --kubeconfig=$KUBECONFIG \
      create -f "$db_service"
  else
    log_proc_msg "Service already exists for db, skipping"
  fi
}

__update_db_ip() {
  log_proc_msg "Updating database service IP"
  local existing_service=$(kubectl \
    --kubeconfig=$KUBECONFIG \
    get services -o json \
    | jq '.items[] | select(.metadata.name == "db")')
  if [ -z "$existing_service" ]; then
    log_proc_error "DB service not created in k8s cluster, exiting"
    exit 1
  else
    log_proc_msg "Found db service, updating IP address"
    local db_ip=$(echo "$existing_service" \
      | jq -r '.spec.clusterIP')
    set_config "DB_IP" "$db_ip"
  fi
}

__cleanup_service() {
  log_proc_msg "Cleaning up configmap for db"

  kubectl --kubeconfig $KUBECONFIG \
    delete service db || true
}

__check_db() {
  log_proc_msg "Checking $COMPONENT container status on: $DB_IP:$DB_PORT"
  platform_exec "check_service_connection" "$DB_IP" "$DB_PORT" "$COMPONENT" "$TIMEOUT"
}

main() {
  __cleanup_service
  __create_db_service
  __update_db_ip
  __check_db
}

main
