#!/bin/bash
set -e
set -o pipefail

__load_config() {
  log_proc_msg "Loading system configuration"
  source "$PIPELINES_CONFIG"
  log_system_info
}

__restart_database() {
  log_proc_msg "Restarting database"
  source "$INSTALLER_SCRIPTS_DIR/restartDb.sh"
}

__boot_installer() {
  log_proc_msg "Restarting installer container"
  platform_exec "boot_installer"
  sleep 10
}

__check_installer() {
  log_proc_msg  "Checking if installer is running"
  local wait_time=3

  _get_installer
  if [ $is_request_success == true ]; then
    log_proc_success  "Installer successfully running"
  else
    log_proc_msg "Installer  not running, retrying in $wait_time seconds"
    sleep $wait_time
    __check_installer
  fi
}

__restart_vault() {
  log_proc_msg "Restarting vault"
  source "$INSTALLER_SCRIPTS_DIR/restartVault.sh"
}

__restart_msg() {
  log_proc_msg "Restarting msg"
  source "$INSTALLER_SCRIPTS_DIR/restartMsg.sh"
}

__restart_redis() {
  log_proc_msg "Restarting redis"
  source "$INSTALLER_SCRIPTS_DIR/restartRedis.sh"
}

__boot_services() {
  log_proc_msg "Booting services"
  local services=("pipelineSync" "runTrigger" "stepTrigger" "cron" "nexec")
  for service in ${services[@]}; do
    local service_data='{"name": "'$service'"}'

    _post_services "$service_data"
    if [ $is_request_success == true ]; then
      log_proc_success "$service started"
    else
      log_proc_error "Error while starting  $service"
      log_proc_error "Status code: $response_status_code"
      exit 1
    fi
  done
}

__boot_www() {
  log_proc_msg "Booting WWW"
  local service='{"name": "www"}'
  _post_services "$service"
  if [ $is_request_success == true ]; then
    log_proc_success "WWW started"
  else
    log_proc_error "Error while starting WWW "
    log_proc_error "Status code: $response_status_code \
      Log file: $LOGS_DIR/www.log"
    exit 1
  fi
}

__boot_api() {
  log_proc_msg "Booting API"
  local service='{"name": "api"}'
  _post_services "$service"
  if [ $is_request_success == true ]; then
    sleep 6
    log_proc_success "API started"
  else
    log_proc_error "Error while starting API"
    log_proc_error "Status code: $response_status_code \
      Log file: $LOGS_DIR/api.log"
    exit 1
  fi
}

main() {
  log_proc_marker  "Restarting services"
  __load_config
  __restart_database
  __boot_installer
  __check_installer
  __restart_vault
  __restart_msg
  __restart_redis
  __boot_api
  __boot_www
  __boot_services
}

main
