#!/bin/bash
set -e
set -o pipefail

export COMPONENT="vault"
export VAULT_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export VAULT_COMPOSE="$VAULT_CONFIG_DIR/vault_compose.yml"

__check_vault() {
  log_proc_msg "Checking vault container status on: $VAULT_IP:$VAULT_PORT"
  platform_exec "check_service_connection" "$VAULT_IP" "$VAULT_PORT" "$COMPONENT"
}

__initialize_vault() {
  log_proc_msg "Initializing vault"
  _post_secrets_initialize
  if [ $is_request_success == true ]; then
    log_proc_success "Vault initialized"
  else
    log_proc_error "Error while initializing vault"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi
}

__restart_vault_compose() {
  log_proc_msg "Restarting vault container"
  docker-compose \
    --file $VAULT_COMPOSE down || true

  docker-compose \
    --file $VAULT_COMPOSE  \
    up \
    --detach $COMPONENT

  log_proc_msg "Vault container successfully running"
}

__restart_vault_kubernetes() {
  log_proc_warn "Vault kubernetes service should be restarted manually"
}

main() {
  log_proc_marker "Restarting Vault"
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    __restart_vault_compose
  else
    __restart_vault_kubernetes
  fi
  __check_vault
  __initialize_vault
}

main
